@@ -5,7 +5,7 @@ package DBIx::SearchBuilder;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "0.88";
+$VERSION = "0.90";
 
 =head1 NAME
 
@@ -108,6 +108,8 @@ sub _DoSearch {
     # The initial SELECT or SELECT DISTINCT is decided later
 
     $QueryString = $self->_BuildJoins . " ";
+    $QueryString .= $self->_WhereClause . " " . $self->{'table_links'} . " "
+      if ( $self->_isLimited > 0 );
 
     # DISTINCT query only required for multi-table selects
     if ($self->_isJoined) {
@@ -115,8 +117,6 @@ sub _DoSearch {
     } else {
         $QueryString = "SELECT main.* FROM $QueryString";
     }
-    $QueryString .= $self->_WhereClause . " " . $self->{'table_links'} . " "
-      if ( $self->_isLimited > 0 );
 
     # TODO: GroupBy won't work with postgres.
     # $QueryString .= $self->_GroupByClause. " ";
@@ -341,13 +341,11 @@ Returns true if this Searchbuilder requires joins between tables
 
 sub _isJoined {
     my $self = shift;
-    if ($self->{'left_joins'} || $self->{'aliases'}) {
+    if (keys(%{$self->{'left_joins'}})) {
         return(1);
     } else {
-        return undef;
-
-     }
-    
+        return(@{$self->{'aliases'}});
+    }
 
 }
 
@@ -788,7 +786,7 @@ sub _GenericRestriction {
 
     # If it's a new value or we're overwriting this sort of restriction,
 
-    if ( $self->_Handle->CaseSensitive ) {
+    if ( $self->_Handle->CaseSensitive && defined $args{'VALUE'} && $args{'VALUE'} ne '' ) {
 
         unless ( $args{'CASESENSITIVE'} ) {
             $QualifiedField = "lower($QualifiedField)";
@@ -933,24 +931,59 @@ ORDER defaults to ASC(ending).  DESC(ending) is also a valid value for OrderBy
 
 sub OrderBy {
     my $self = shift;
-    my %args = ( ALIAS => 'main',
-                 FIELD => undef,
-                 ORDER => 'ASC',
-                 @_ );
-    $self->{'order_by_alias'} = $args{'ALIAS'};
-    $self->{'order_by_field'} = $args{'FIELD'};
-    if ( $args{'ORDER'} =~ /^des/i ) {
-        $self->{'order_by_order'} = "DESC";
-    }
-    else {
-        $self->{'order_by_order'} = "ASC";
-    }
-
-    $self->RedoSearch();
+    my %args = ( @_ );
 
+    $self->OrderByCols( \%args );
 }
 
-# }}}
+=head2 OrderByCols ARRAY
+
+OrderByCols takes an array of paramhashes of the form passed to OrderBy.
+The result set is ordered by the items in the array.
+
+=cut
+
+sub OrderByCols {
+    my $self = shift;
+    my @args = @_;
+    my $row;
+    my $clause;
+
+    foreach $row ( @args ) {
+
+        my %rowhash = ( ALIAS => 'main',
+			FIELD => undef,
+			ORDER => 'ASC',
+			%$row
+		      );
+        if ($rowhash{'ORDER'} =~ /^des/i) {
+	    $rowhash{'ORDER'} = "DESC";
+        }
+        else {
+	    $rowhash{'ORDER'} = "ASC";
+        }
+
+        if ( ($rowhash{'ALIAS'}) and
+	     ($rowhash{'FIELD'}) and
+             ($rowhash{'ORDER'}) ) {
+
+            $clause .= ($clause ? ", " : " ");
+            $clause .= $rowhash{'ALIAS'} . ".";
+            $clause .= $rowhash{'FIELD'} . " ";
+            $clause .= $rowhash{'ORDER'};
+        }
+    }
+
+    if ($clause) {
+	$self->{'order_clause'} = "ORDER BY" . $clause;
+    }
+    else {
+	$self->{'order_clause'} = "";
+    }
+    $self->RedoSearch();
+}
+
+# }}} 
 
 # {{{ sub _OrderClause
 
@@ -963,26 +996,10 @@ returns the ORDER BY clause for the search.
 sub _OrderClause {
     my $self = shift;
 
-    my $clause = "";
-
-    #If we don't have an order defined, set the defaults
-    unless ( defined $self->{'order_by_field'} ) {
-        $self->OrderBy();
+    unless ( defined $self->{'order_clause'} ) {
+	return "";
     }
-
-    if (     ( $self->{'order_by_field'} )
-         and ( $self->{'order_by_alias'} )
-         and ( $self->{'order_by_order'} ) ) {
-
-        $clause = "ORDER BY ";
-        $clause .= $self->{'order_by_alias'} . "."
-          if ( $self->{'order_by_alias'} );
-        $clause .= $self->{'order_by_field'};
-        $clause .= " " . $self->{'order_by_order'}
-          if ( $self->{'order_by_order'} );
-    }
-
-    return ($clause);
+    return ($self->{'order_clause'});
 }
 
 # }}}
@@ -1216,6 +1233,8 @@ Returns the number of records in the set.
 
 =cut
 
+
+
 sub Count {
     my $self = shift;
 
